1.16.1 — Rucio 1.2 documentation

# 1.16.1

## General

### Enhancements

- Core & Internals: Authz: Signed URL support #1054
- Core & Internals: core: exception handler truncates some error messages #1116
- Core & Internals: schema: add root and webdav functional test for atlas #1117
- Messaging: Create a new RULE_OK notification for all rules #1115

### Bugs

- Core & Internals: core.account_limit.get_rse_account_usage should liste accounts who have usage, but no quota #1045
- Core & Internals: regex for dids in cms schema not matching ‘-‘ #1128
- Transfers: Transfers : Bug with verify checksum #1118

## Clients

### Enhancements

- Clients: list-rules CLI should give a warning if it does not find a rule but looks on content of a container/DS #1077
- Testing: Extend the client validation with test_bin_rucio.py on Travis #1036

### Bugs

- Clients: Fix in rucio/bin, empty md5 #1104

## WebUI

### Enhancements

- WebUI: lifetime field for rule creation should be pre-filled with 180 days #1127